sphinx_gallery.backreferences — Python documentation

# sphinx_gallery.backreferences

## Backreferences Generator

Parses example file code in order to keep track of used functions

### Functions

`sphinx_gallery.backreferences.` `identify_names`(script_blocks, global_variables=None, node='')

  Build a codeobj summary by identifying and resolving used names.

#### Examples using `sphinx_gallery.backreferences.identify_names`

Link to other packages

### Classes

class `sphinx_gallery.backreferences.` `DummyClass`

  Dummy class for testing method resolution.

  property `prop`

    Property.

  `run`()

    Do nothing.

#### Examples using `sphinx_gallery.backreferences.DummyClass`

Link to other packages

class `sphinx_gallery.backreferences.` `NameFinder`(global_variables=None)

  Finds the longest form of variable names and their imports in code.

  Only retains names from imported modules.

#### Examples using `sphinx_gallery.backreferences.NameFinder`

Test __future__ imports across cells